Statistics for the annual expectations of economic indicators: mean, median, standard deviate, minimum, maximum and the coefficient of variation. All statistics are computed based on annual expectations provided by many financial institutions in Brazil: banks, funds, risk managers, so on and so forth. These expections and its statistics are used to build the FOCUS Report weekly released by the Brazilian Central Bank.
get_annual_market_expectations(indic, start_date = NULL, end_date = NULL,
...)a character vector with economic indicators names: Balan<U+00E7>a Comercial, Balan<U+00E7>o de Pagamentos, Fiscal, IGP-DI, IGP-M, INPC, IPA-DI, IPA-M, IPCA, IPCA-15, IPC-Fipe, Pre<U+00E7>os administrados por contrato e monitorados, Produ<U+00E7><U+00E3>o industrial, PIB Agropecu<U+00E1>ria, PIB Industrial, PIB Servi<U+00E7>os, PIB Total, Meta para taxa over-selic, Taxa de c<U+00E2>mbio. They are case sensitive and don't forget the accents.
series initial date. Accepts ISO character formated date and Date.
series final date. Accepts ISO character formated date and Date.
additional parameters to be passed to the API
indic argumento must be one of these: Balan<U+00E7>a Comercial,
Balan<U+00E7>o de Pagamentos, Fiscal, IGP-DI, IGP-M, INPC, IPA-DI, IPA-M, IPCA, IPCA-15, IPC-Fipe,
Pre<U+00E7>os administrados por contrato e monitorados, Produ<U+00E7><U+00E3>o industrial, PIB Agropecu<U+00E1>ria,
PIB Industrial, PIB Servi<U+00E7>os, PIB Total, Meta para taxa over-selic, Taxa de c<U+00E2>mbio.
Respecting the case, blank spaces and accents.
The ... is to be used with API's parameters. $top to specify
the maximum number of rows to be returned, this returns the $top rows,
in chronological order. There is also $skip to ignore the first rows.
A data.frame with the following ten columns: date, indic,
indic_detail, reference_year, mean, median, sd,
coefvar, min, max.
There are annual expectations available for the following indicators: Balan<U+00E7>a Comercial, Balan<U+00E7>o de Pagamentos, Fiscal, IGP-DI, IGP-M, INPC, IPA-DI, IPA-M, IPCA, IPCA-15, IPC-Fipe, Pre<U+00E7>os administrados por contrato e monitorados, Produ<U+00E7><U+00E3>o industrial, PIB Agropecu<U+00E1>ria, PIB Industrial, PIB Servi<U+00E7>os, PIB Total, Meta para taxa over-selic, Taxa de c<U+00E2>mbio.
# NOT RUN {
indic <- c("Balan<U+00E7>o de Pagamentos", "Fiscal")
end_date <- "2018-01-31"
x <- get_annual_market_expectations(indic, end_date = end_date, `$top` = 10)
# }
Run the code above in your browser using DataLab