Learn R Programming

rbcb (version 0.1.14)

rbcb_get: Gets data from BCB open data services

Description

Gets SGS, currency, market expectations and many other datasets from the Brazilian Central Bank open data services.

Usage

rbcb_get(x, ...)

# S3 method for sgs rbcb_get(x, from = NULL, to = NULL, last = 0, ...)

Value

a dataset with the corresponding data (usually a `tibble`)

Arguments

x

an object that represents the kind of data to be downloaded

...

others arguments

from

series initial date. Accepts ISO character formated date and Date.

to

series final date. Accepts ISO character formated date and Date.

last

last items of the series

To use the SGS API a `sgs` object should be passed.

Examples

Run this code
if (FALSE) {
x <- sgs(USD = 1, SELIC = 1178)
rbcb_get(x, from = Sys.Date() - 10)
}

Run the code above in your browser using DataLab