search_series: Search for series in dadosabertos.bcb.gov.br site
Description
Search for series in dadosabertos.bcb.gov.br site
Usage
search_series(q, page = 1)
Arguments
q
query string
page
page number to visualize of returning search
The page argument defaults to 1 which shows the first page of a returning search.
The search results also show the number of pages and the other pages can be showed by changing
this argument to the page to be presented.