Learn R Programming

rbcb (version 0.1.14)

sgs: Create SGS code

Description

SGS code is an objects that represents the SGS code used to download datasets from the SGS API.

Usage

sgs(..., load_info = TRUE)

Value

an SGS object representing SGS codes

Arguments

...

numeric codes (preferably named)

load_info

`logical` indicating with the dataset info shoud be loaded (default TRUE)

Examples

Run this code
if (FALSE) {
sgs(USD = 1, IPCA = 433)
}

Run the code above in your browser using DataLab