powered by
Gets SGS, currency, market expectations and many other datasets from the Brazilian Central Bank open data services.
rbcb_get(x, ...)# S3 method for sgs rbcb_get(x, from = NULL, to = NULL, last = 0, ...)
# S3 method for sgs rbcb_get(x, from = NULL, to = NULL, last = 0, ...)
a dataset with the corresponding data (usually a `tibble`)
an object that represents the kind of data to be downloaded
others arguments
series initial date. Accepts ISO character formated date and Date.
Date
series final date. Accepts ISO character formated date and Date.
last items of the series
To use the SGS API a `sgs` object should be passed.
if (FALSE) { x <- sgs(USD = 1, SELIC = 1178) rbcb_get(x, from = Sys.Date() - 10) }
Run the code above in your browser using DataLab