powered by
SGS code is an objects that represents the SGS code used to download datasets from the SGS API.
sgs(..., load_info = TRUE)
an SGS object representing SGS codes
numeric codes (preferably named)
`logical` indicating with the dataset info shoud be loaded (default TRUE)
if (FALSE) { sgs(USD = 1, IPCA = 433) }
Run the code above in your browser using DataLab